==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebPaneDragOverEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragOverEventArgsDetailDescriptionMetadata } from "./WebPaneDragOverEventArgsDetailDescriptionMetadata";
import { WebPaneDragOverEventArgsDescription } from "./WebPaneDragOverEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneDragOverEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragOverEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragOverEventArgsDescriptionMetadata.a == null) {
                WebPaneDragOverEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragOverEventArgsDescriptionMetadata.c(WebPaneDragOverEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPaneDragOverEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPaneDragOverEventArgsDescriptionMetadata.a);
            WebPaneDragOverEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragOverEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPaneDragOverEventArgsDetail");
        }
        static d(a) {
            WebPaneDragOverEventArgsDescriptionMetadata.b(a);
            a.ad("WebPaneDragOverEventArgs", () => new WebPaneDragOverEventArgsDescription());
            a.ac("WebPaneDragOverEventArgs", WebPaneDragOverEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneDragOverEventArgsDescriptionMetadata.$t = markType(WebPaneDragOverEventArgsDescriptionMetadata, 'WebPaneDragOverEventArgsDescriptionMetadata');
    WebPaneDragOverEventArgsDescriptionMetadata.a = null;
    return WebPaneDragOverEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebPaneDragOverEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragOverEventArgsDetailDescriptionMetadata } from "./WebPaneDragOverEventArgsDetailDescriptionMetadata";
import { WebPaneDragOverEventArgsDescription } from "./WebPaneDragOverEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneDragOverEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragOverEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragOverEventArgsDescriptionMetadata.a == null) {
                WebPaneDragOverEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragOverEventArgsDescriptionMetadata.c(WebPaneDragOverEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPaneDragOverEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPaneDragOverEventArgsDescriptionMetadata.a);
            WebPaneDragOverEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragOverEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPaneDragOverEventArgsDetail");
        }
        static d(a) {
            WebPaneDragOverEventArgsDescriptionMetadata.b(a);
            a.ae("WebPaneDragOverEventArgs", () => new WebPaneDragOverEventArgsDescription());
            a.ad("WebPaneDragOverEventArgs", WebPaneDragOverEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneDragOverEventArgsDescriptionMetadata.$t = markType(WebPaneDragOverEventArgsDescriptionMetadata, 'WebPaneDragOverEventArgsDescriptionMetadata');
    WebPaneDragOverEventArgsDescriptionMetadata.a = null;
    return WebPaneDragOverEventArgsDescriptionMetadata;
})();
